@@ -1,20 +1,28 @@
 """
-cli.py - Entry point for savecode system. Aggregates plugins to gather and save Python code.
+savecode/cli.py - Entry point for savecode system. Aggregates plugins to gather and save Python code.
 """
 
 import argparse
 import os
+from typing import Any, Dict, List
 from savecode import __version__
 # Import the plugins package to ensure all plugins are registered.
 import savecode.plugins
 from savecode.manager.manager import run_plugins
 from savecode.utils.output_manager import configure_output_path
+from savecode.utils.colors import GREEN, BLUE, CYAN, RESET
+from savecode.utils.logger import configure_logging  # Import centralized logging configuration
+from savecode.utils.display import display_summary     # Import display module for summary output
 
-def main():
+def main() -> None:
     """
     Main entry point for the savecode CLI.
-    Parses command-line arguments, builds a shared context, and runs the plugins.
+    Parses command-line arguments, builds a shared context, runs the plugins,
+    and displays a summary of the saved files.
     """
+    # Configure centralized logging
+    configure_logging()
+    
     parser = argparse.ArgumentParser(
         description="Save the full code from Python files in specified directories and individual files to a single output file."
     )
@@ -52,7 +60,7 @@ def main():
     args, extra_args = parser.parse_known_args()
     
     # Build a shared context for all plugins.
-    context = {
+    context: Dict[str, Any] = {
         'roots': args.roots,
         'files': args.files,
         'skip': args.skip,
@@ -62,52 +70,8 @@ def main():
     
     run_plugins(context)
     
-    # After plugins run, display a summary.
-    all_py_files = context.get('all_py_files', [])
-    green = "\033[1;32m"
-    blue = "\033[1;34m"
-    cyan = "\033[1;36m"
-    reset = "\033[0m"
-    print(f"\n{cyan}Saved code from {len(all_py_files)} files to {context['output']}{reset}")
-    print(f"\n{green}Files saved:{reset}")
-    for f in all_py_files:
-        # Convert each absolute file path to a relative path from the current working directory.
-        rel_path = os.path.relpath(f, os.getcwd())
-        print(f"{blue}- {rel_path}{reset}")
-    print("\n")
+    # Display a summary of the saved files using the centralized display function.
+    display_summary(context)
     
 if __name__ == "__main__":
-    main()
-   
-   # RELEASE PROCESS:
-# ----------------
-# 1. Update the version in setup.py and savecode/__init__.py.
-#
-# 2. Commit your changes.
-#
-# 3. Create a release tag with a 'v' prefix (e.g., "v*.*.*"):
-#      git tag v*.*.*
-#
-# 4. Push your tags (if your remote isn't named 'origin', use its name):
-#      git push origin --tags
-#
-# 5. The GitHub Actions workflow (in .github/workflows/publish.yml) is triggered by
-#    tag pushes (tags matching "v*") to automatically build and publish your package to PyPI.
-#
-# Note: Regular commits don't trigger the release workflow—only pushing a new tag does.
-
-# -----------
-
-# Clear Dist: rm -rf dist/
-
-# Clear Build: rm -rf build/
-
-# Build: python -m build
-
-# Add Tag: git tag v*.*.*
-
-#Git Push Origin
-
-# Push: git push origin --tags
-
-# -----------
\ No newline at end of file
+    main()
\ No newline at end of file
