@@ -1,16 +1,27 @@
 """
-savecode/plugins/save.py - Plugin to save code from Python files into a single output file.
+savecode/plugins/save.py - Plugin to save code from Python files into a single output file with enhanced error handling.
 """
 
 import os
+import sys
+import logging
+from typing import Any, Dict, List
 from savecode.manager.manager import register_plugin
 
+logger = logging.getLogger(__name__)
+
 @register_plugin
 class SavePlugin:
     """
-    Plugin that reads Python files and writes their content to a designated output file.
+    Plugin that reads Python files and writes their content to a designated output file with enhanced error handling.
+    
+    Fatal error:
+      - If the output file cannot be written, the process will terminate with a nonzero exit code.
+      
+    Non-fatal error:
+      - If individual files cannot be read, the error is logged and processing continues.
     """
-    def run(self, context):
+    def run(self, context: Dict[str, Any]) -> None:
         """
         Execute the saving process.
         
@@ -18,8 +29,8 @@ class SavePlugin:
           - 'all_py_files': list of Python file paths gathered by the GatherPlugin.
           - 'output': the output file path where the combined code should be saved.
         """
-        all_py_files = context.get('all_py_files', [])
-        output_file = context.get('output', "./temp.txt")
+        all_py_files: List[str] = context.get('all_py_files', [])
+        output_file: str = context.get('output', "./temp.txt")
         try:
             with open(output_file, 'w', encoding='utf-8') as out:
                 # Write a summary header at the beginning of the file.
@@ -38,7 +49,8 @@ class SavePlugin:
                             out.write(header)
                             out.write(f.read())
                             out.write("\n\n")
-                    except Exception as e:
-                        print(f"Error reading {file}: {e}")
-        except Exception as e:
-            print(f"Error writing to output file {output_file}: {e}")
\ No newline at end of file
+                    except (OSError, UnicodeDecodeError) as e:
+                        logger.error("Error reading %s: %s", file, e)
+        except OSError as e:
+            logger.error("Error writing to output file %s: %s", output_file, e)
+            sys.exit(1)  # Terminate the program if the output file cannot be written
\ No newline at end of file
